# 20230517_v0.9.13_large_offset_crab_tuned

DL1ab step to apply NSB tuning for Crab gamma diffuse MC.

lstchain config taken from '20221027_v0.9.9_crab_tuned'


Contact : Mathieu de Bony, Mathieu de Bony, Léo Le Moigne, David Sanchez


